==> openshift-model-config-6.6.2-sources.jar: io/fabric8/openshift/api/model/config/v1/IngressListFluent.java <==
package io.fabric8.openshift.api.model.config.v1;

import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import io.fabric8.kubernetes.api.builder.Fluent;
import io.fabric8.kubernetes.api.builder.Nested;
import java.util.ArrayList;
import java.lang.String;
import io.fabric8.kubernetes.api.model.ListMeta;
import java.util.LinkedHashMap;
import java.util.function.Predicate;
import java.lang.Integer;
import java.lang.Deprecated;
import java.lang.Long;
import java.util.Iterator;
import java.util.Collection;
import java.lang.Object;
import java.util.List;
import java.lang.Boolean;
import java.util.Map;

 /**
  * Generated
  */
public interface IngressListFluent<A extends IngressListFluent<A>> extends Fluent<A>{
  public String getApiVersion();
  public A withApiVersion(String apiVersion);
  public Boolean hasApiVersion();
  public A addToItems(Integer index,Ingress item);
  public A setToItems(Integer index,Ingress item);
  public A addToItems(io.fabric8.openshift.api.model.config.v1.Ingress... items);
  public A addAllToItems(Collection<Ingress> items);
  public A removeFromItems(io.fabric8.openshift.api.model.config.v1.Ingress... items);
  public A removeAllFromItems(Collection<Ingress> items);
  public A removeMatchingFromItems(Predicate<IngressBuilder> predicate);
  
  /**
   * This method has been deprecated, please use method buildItems instead.
   * @return The buildable object.
   */
  @Deprecated
  public List<Ingress> getItems();
  public List<Ingress> buildItems();
  public Ingress buildItem(Integer index);
  public Ingress buildFirstItem();
  public Ingress buildLastItem();
  public Ingress buildMatchingItem(Predicate<IngressBuilder> predicate);
  public Boolean hasMatchingItem(Predicate<IngressBuilder> predicate);
  public A withItems(List<Ingress> items);
  public A withItems(io.fabric8.openshift.api.model.config.v1.Ingress... items);
  public Boolean hasItems();
  public IngressListFluent.ItemsNested<A> addNewItem();
  public IngressListFluent.ItemsNested<A> addNewItemLike(Ingress item);
  public IngressListFluent.ItemsNested<A> setNewItemLike(Integer index,Ingress item);
  public IngressListFluent.ItemsNested<A> editItem(Integer index);
  public IngressListFluent.ItemsNested<A> editFirstItem();
  public IngressListFluent.ItemsNested<A> editLastItem();
  public IngressListFluent.ItemsNested<A> editMatchingItem(Predicate<IngressBuilder> predicate);
  public String getKind();
  public A withKind(String kind);
  public Boolean hasKind();
  public ListMeta getMetadata();
  public A withMetadata(ListMeta metadata);
  public Boolean hasMetadata();
  public A withNewMetadata(String _continue,Long remainingItemCount,String resourceVersion,String selfLink);
  public A addToAdditionalProperties(String key,Object value);
  public A addToAdditionalProperties(Map<String,Object> map);
  public A removeFromAdditionalProperties(String key);
  public A removeFromAdditionalProperties(Map<String,Object> map);
  public Map<String,Object> getAdditionalProperties();
  public <K,V>A withAdditionalProperties(Map<String,Object> additionalProperties);
  public Boolean hasAdditionalProperties();
  public interface ItemsNested<N> extends Nested<N>,IngressFluent<IngressListFluent.ItemsNested<N>>{
    public N and();
    public N endItem();
    
  }
  
}

==> openshift-model-config-6.7.2-sources.jar: io/fabric8/openshift/api/model/config/v1/IngressListFluent.java <==
package io.fabric8.openshift.api.model.config.v1;

import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import com.fasterxml.jackson.annotation.JsonIgnore;
import com.fasterxml.jackson.annotation.JsonProperty;
import io.fabric8.kubernetes.api.builder.Fluent;
import io.fabric8.kubernetes.api.builder.Nested;
import java.util.ArrayList;
import java.lang.String;
import io.fabric8.kubernetes.api.model.ListMeta;
import java.util.LinkedHashMap;
import java.util.function.Predicate;
import java.lang.Deprecated;
import java.lang.Long;
import java.util.Iterator;
import java.util.Collection;
import java.lang.Object;
import java.util.List;
import java.lang.Boolean;
import java.util.Map;

 /**
  * Generated
  */
public interface IngressListFluent<A extends IngressListFluent<A>> extends Fluent<A>{
  public String getApiVersion();
  public A withApiVersion(String apiVersion);
  public Boolean hasApiVersion();
  public A addToItems(int index,Ingress item);
  public A setToItems(int index,Ingress item);
  public A addToItems(io.fabric8.openshift.api.model.config.v1.Ingress... items);
  public A addAllToItems(Collection<Ingress> items);
  public A removeFromItems(io.fabric8.openshift.api.model.config.v1.Ingress... items);
  public A removeAllFromItems(Collection<Ingress> items);
  public A removeMatchingFromItems(Predicate<IngressBuilder> predicate);
  
  /**
   * This method has been deprecated, please use method buildItems instead.
   * @return The buildable object.
   */
  @Deprecated
  public List<Ingress> getItems();
  public List<Ingress> buildItems();
  public Ingress buildItem(int index);
  public Ingress buildFirstItem();
  public Ingress buildLastItem();
  public Ingress buildMatchingItem(Predicate<IngressBuilder> predicate);
  public Boolean hasMatchingItem(Predicate<IngressBuilder> predicate);
  public A withItems(List<Ingress> items);
  public A withItems(io.fabric8.openshift.api.model.config.v1.Ingress... items);
  public Boolean hasItems();
  public IngressListFluent.ItemsNested<A> addNewItem();
  public IngressListFluent.ItemsNested<A> addNewItemLike(Ingress item);
  public IngressListFluent.ItemsNested<A> setNewItemLike(int index,Ingress item);
  public IngressListFluent.ItemsNested<A> editItem(int index);
  public IngressListFluent.ItemsNested<A> editFirstItem();
  public IngressListFluent.ItemsNested<A> editLastItem();
  public IngressListFluent.ItemsNested<A> editMatchingItem(Predicate<IngressBuilder> predicate);
  public String getKind();
  public A withKind(String kind);
  public Boolean hasKind();
  public ListMeta getMetadata();
  public A withMetadata(ListMeta metadata);
  public Boolean hasMetadata();
  public A withNewMetadata(String _continue,Long remainingItemCount,String resourceVersion,String selfLink);
  public A addToAdditionalProperties(String key,Object value);
  public A addToAdditionalProperties(Map<String,Object> map);
  public A removeFromAdditionalProperties(String key);
  public A removeFromAdditionalProperties(Map<String,Object> map);
  public Map<String,Object> getAdditionalProperties();
  public <K,V>A withAdditionalProperties(Map<String,Object> additionalProperties);
  public Boolean hasAdditionalProperties();
  public interface ItemsNested<N> extends Nested<N>,IngressFluent<IngressListFluent.ItemsNested<N>>{
    public N and();
    public N endItem();
    
  }
  
}
